@@ -12,8 +12,8 @@
 #include <X11/extensions/shape.h>
 #include <sensors/sensors.h>
 #include <sensors/error.h>
-#include "wmgeneral/wmgeneral.h"
-#include "wmgeneral/misc.h"
+#include <libdockapp/wmgeneral.h>
+#include <libdockapp/misc.h>
 #include "wmgtemp-interface.xpm"
 #include "wmgtemp-interface-mask.xbm"
 #include <math.h>
@@ -70,15 +70,15 @@ void draw_range_line(double temp, double range, short type);
 void update_display();
 void update_sensor_data();
 void do_sensors(int val);
-inline double highest_temp(double *temp_array);
-inline double lowest_temp(double *temp_array);
-inline void draw_temp(short value, int type);
-inline void draw_warning_lights(double current_temp);
-inline void draw_max(int type);
-inline void blank_max(int type);
-inline void draw_type(int type);
-inline void blank_type(int type);
-inline void cycle_temptype();
+double highest_temp(double *temp_array);
+double lowest_temp(double *temp_array);
+void draw_temp(short value, int type);
+void draw_warning_lights(double current_temp);
+void draw_max(int type);
+void blank_max(int type);
+void draw_type(int type);
+void blank_type(int type);
+void cycle_temptype();
 
 /* Globals */
 int delay      = 1;
@@ -117,7 +117,6 @@ char *sensor_chip = NULL;
 short quiet = 0;
 
 int main(int argc, char **argv) {
-  char *chipname = NULL;
   int chip_nr = 0;
   int i = 0;
   int tmp_swap;
@@ -162,10 +161,7 @@ int main(int argc, char **argv) {
       }
     }
 
-    if(chip_found == 1) {
-      chipname = name->prefix;
-    }
-    else {
+    if(chip_found == -1) {
       name = sensors_get_detected_chips(NULL, &chip_nr);
     }
   }
@@ -428,7 +424,7 @@ void update_sensor_data() {
   double sys_high = highest_temp(sys_history);
 
   /* Shift the arrays */
-  for(i = 0; i < 59; i++) {
+  for(i = 0; i < 58; i++) {
     cpu_history[i] = cpu_history[i + 1];
     sys_history[i] = sys_history[i + 1];
   }
@@ -572,7 +568,7 @@ int recompute_range(double cpu_high, double cpu_low, double sys_high, double sys
   return modified;
 }
 
-inline double highest_temp(double *temp_array) {
+double highest_temp(double *temp_array) {
   int i = 0;
   double high = 0;
   for(i = 0; i < 59; i++) {
@@ -582,7 +578,7 @@ inline double highest_temp(double *temp_array) {
   return high;
 }
 
-inline double lowest_temp(double *temp_array) {
+double lowest_temp(double *temp_array) {
   int i = 0;
   double low = 500;
   for(i = 0; i < 59; i++) {
@@ -620,7 +616,7 @@ void add_to_graph(double temp, int type, short blank, double range, int pos) {
 }
 
 
-inline void draw_temp(short value, int type) {
+void draw_temp(short value, int type) {
   short digit;
 
   if(value > 0) {
@@ -638,7 +634,7 @@ inline void draw_temp(short value, int type) {
 }
 
 
-inline void draw_clear_temps() {
+void draw_clear_temps() {
   if(IsOn(SENSOR_DISP, CPU)) {
     copyXPMArea(78, 65, 5, 7, 34, CPU_YPOS);
     copyXPMArea(78, 65, 5, 7, 40, CPU_YPOS);
@@ -663,11 +659,15 @@ int init_sensors() {
   FILE *config_file;
   int res;
 
-  config_file = fopen(rc_config, "r");
+  if (rc_config) {
+    config_file = fopen(rc_config, "r");
 
-  if(config_file == NULL) {
-    fprintf(stderr, "Error opening %s\n", rc_config);
-    return 0;
+    if(config_file == NULL) {
+      fprintf(stderr, "Error opening %s\n", rc_config);
+      return 0;
+    }
+  } else {
+    config_file = NULL; /* Use libsensors default */
   }
 
   res = sensors_init(config_file);
@@ -677,18 +677,18 @@ int init_sensors() {
     return 0;
   }
 
-  if(fclose(config_file))
+  if(config_file && fclose(config_file))
     perror("Error closing sensors config");
 
   return 1;
 }
 
 void display_usage() {
-  printf("wmgtemp v0.9\n" \
+  printf("wmgtemp v"PACKAGE_VERSION"\n" \
 	 "Usage: wmgtemp [options]\n" \
 	 "Options:\n" \
 	 "   -S, --sensorconf=PATH  Specify sensors config file PATH\n" \
-	 "                          [Default: /etc/sensors.conf]\n" \
+	 "                          [Default: autodetect]\n" \
 	 "   -s, --scale=SCALE      Display temperatures in SCALE\n" \
 	 "                          SCALE=kelvin, fahrenheit\n" \
 	 "                          [Default: celcius]\n" \
@@ -745,7 +745,7 @@ void draw_warning_lights(double current_temp) {
   }
 }
 
-inline void blank_type(int type) {
+void blank_type(int type) {
   switch(type) {
   case CPU:
     copyXPMArea(78, 65, 5, 7, 11, CPU_YPOS);
@@ -776,17 +776,17 @@ inline void blank_type(int type) {
   }
 }
 
-inline void draw_max(int type) {
+void draw_max(int type) {
   //  copyXPMArea(1, 81, 17, 7, 11, type == CPU ? CPU_YPOS : SYS_YPOS);
   copyXPMArea(24, 75, 4, 3, 29, type == CPU ? CPU_YPOS : SYS_YPOS);
 }
 
-inline void blank_max(int type) {
+void blank_max(int type) {
   //  copyXPMArea(1, 81, 17, 7, 11, type == CPU ? CPU_YPOS : SYS_YPOS);
   copyXPMArea(20, 75, 4, 3, 29, type == CPU ? CPU_YPOS : SYS_YPOS);
 }
 
-inline void draw_type(int type) {
+void draw_type(int type) {
   switch(type) {
   case CPU:
     copyXPMArea(65, 40, 17, 7, 11, CPU_YPOS);
@@ -797,7 +797,7 @@ inline void draw_type(int type) {
   }
 }
 
-inline void cycle_temptype() {
+void cycle_temptype() {
   if(IsOn(SENSOR_DISP, TSCALE_CELCIUS)) {
     BitOff(SENSOR_DISP, TSCALE_CELCIUS);
     BitOn(SENSOR_DISP, TSCALE_KELVIN);
@@ -950,9 +950,6 @@ int process_config(int argc, char **argv) {
   if(rc_chip != NULL) {
     sensor_chip = strdup(rc_chip);
   }
-  if(rc_config == NULL) {
-    rc_config = "/etc/sensors.conf";
-  }
 
   if(rc_graph != NULL) {
     if(!strncmp(rc_graph, "l", 1)) {
